@@ -8,7 +8,7 @@ function Point(x, y, z) {
     this.x = x[0];
     this.y = x[1];
     this.z = x[2] || 0.0;
-  }else if(typeof x === 'object'){
+  } else if(typeof x === 'object') {
     this.x = x.x;
     this.y = x.y;
     this.z = x.z || 0.0;
@@ -17,8 +17,7 @@ function Point(x, y, z) {
     this.x = parseFloat(coords[0], 10);
     this.y = parseFloat(coords[1], 10);
     this.z = parseFloat(coords[2], 10) || 0.0;
-  }
-  else {
+  } else {
     this.x = x;
     this.y = y;
     this.z = z || 0.0;
@@ -32,4 +31,4 @@ Point.fromMGRS = function(mgrsStr) {
 Point.prototype.toMGRS = function(accuracy) {
   return mgrs.forward([this.x, this.y], accuracy);
 };
-module.exports = Point;
\ No newline at end of file
+module.exports = Point;
