@@ -3,6 +3,7 @@ module.exports = function(crs, denorm, point) {
     yin = point.y,
     zin = point.z || 0.0;
   var v, t, i;
+  var out = {};
   for (i = 0; i < 3; i++) {
     if (denorm && i === 2 && point.z === undefined) {
       continue;
@@ -21,25 +22,25 @@ module.exports = function(crs, denorm, point) {
     }
     switch (crs.axis[i]) {
     case 'e':
-      point[t] = v;
+      out[t] = v;
       break;
     case 'w':
-      point[t] = -v;
+      out[t] = -v;
       break;
     case 'n':
-      point[t] = v;
+      out[t] = v;
       break;
     case 's':
-      point[t] = -v;
+      out[t] = -v;
       break;
     case 'u':
       if (point[t] !== undefined) {
-        point.z = v;
+        out.z = v;
       }
       break;
     case 'd':
       if (point[t] !== undefined) {
-        point.z = -v;
+        out.z = -v;
       }
       break;
     default:
@@ -47,5 +48,5 @@ module.exports = function(crs, denorm, point) {
       return null;
     }
   }
-  return point;
+  return out;
 };
