@@ -4,7 +4,7 @@
   //        1 is latitude ...
   //        In the later case, grid object gets bigger !!!!
   //        Solution 1 is chosen based on pj_gridinfo.c
-exports.null = { // name of grid's file
+exports['null'] = { // name of grid's file
   "ll": [-3.14159265, - 1.57079633], // lower-left coordinates in radians (longitude, latitude):
   "del": [3.14159265, 1.57079633], // cell's size in radians (longitude, latitude):
   "lim": [3, 3], // number of nodes in longitude, latitude (including edges):
@@ -20,4 +20,4 @@ exports.null = { // name of grid's file
     [0.0, 0.0],
     [0.0, 0.0] // }
   ]
-};
\ No newline at end of file
+};
