@@ -1,12 +1,16 @@
-var D2R = 0.01745329251994329577;
+var adjust_zone = require('../common/adjust_zone');
 var tmerc = require('./tmerc');
+
 exports.dependsOn = 'tmerc';
+
 exports.init = function() {
-  if (!this.zone) {
-    return;
+  var zone = adjust_zone(this.zone, this.long0);
+  if (zone === undefined) {
+    throw new Error('unknown utm zone');
   }
+
   this.lat0 = 0;
-  this.long0 = ((6 * Math.abs(this.zone)) - 183) * D2R;
+  this.long0 = (zone + 0.5) * Math.PI / 30 - Math.PI;
   this.x0 = 500000;
   this.y0 = this.utmSouth ? 10000000 : 0;
   this.k0 = 0.9996;
@@ -15,4 +19,5 @@ exports.init = function() {
   this.forward = tmerc.forward;
   this.inverse = tmerc.inverse;
 };
+
 exports.names = ["Universal Transverse Mercator System", "utm"];
