@@ -5,7 +5,9 @@ VERSION=$(npm ls --json=true proj4js | grep version | awk '{ print $2}'| sed -e
 
 # Build
 git checkout -b build
-grunt
+echo "module.exports = '$VERSION';" > ./lib/version-browser.js
+git add ./lib/version-browser.js -f
+node_modules/.bin/grunt
 git add dist -f
 git commit -m "build $VERSION"
 
@@ -15,8 +17,7 @@ git push --tags git@github.com:proj4js/proj4js.git $VERSION
 
 # Publish
 npm publish
-jam publish
 
 # Cleanup
 git checkout master
-git branch -D build
\ No newline at end of file
+git branch -D build
